Option Explicit
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
' RunSameProjectWith2Sources.vbs
'-----------------------------------------------------------------------
' This vb script will connect to a Repository and server and run an
' EG project that refers to data in that repository and on the requested
' server.  The script will then change the repository and connect to a
' new repository that contains data with the same name on a server with
' the same name.
'
' Although the servername and data name are the same, the data that is
' stored in each repository could be different and provide different
' results.
'
' Once a project is run, the project with the new data will be saved
' locally to the client PC.  The result will be 2 different projects
' on the client machine with results of running the same process on
' 2 different sets of data.
'
' NOTE:
' This type of program could be useful if you have different servers that
' contain different data stored in the same hierarchy on both servers.  For
' example, you may have a repository for an R&D Division and another for HR.  
' Both repositories may have employee datasets stored on a server called
' Administration.  The same EG project could be run against the different
' datasets and the results would be specific to the R&D Divsion or the HR
' Division.
'
' Program Requirement:
' Valid Profiles must be defined within EG for the client that is running
' this script.  The variables 'profile1' and 'profile2' must be set to
' match a valid profile name from within the list of profiles.
'
' The user running this program must have permissions and valid credentials
' for the repositories and servers that are referenced in this script and
' in the project that is being run.
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
' Main Code Section
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
Dim app            'The EG 4.2 application
Call dowork        'This is the main worker subroutine

'------------------------------------------
' close the application before exiting
'------------------------------------------
If not (app Is Nothing) Then
    app.Quit
    Set app = Nothing
End If

MsgBox "Done"
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
' End Main Code Section
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
' Subroutines
'-----------------------------------------------------------------------
'-----------------------------------------------------------------------
'------------------------------------------------------------------------------
' dowork
'------------------------------------------------------------------------------
' This subroutine is where the work is done within the script.  It is the flow 
' controller and the main subroutine in the script.
'
' This dowork subroutine will connect to a repository/server combination based
' on the connection information that is available on the client PC.  It will
' then run a project called "Test2ServersProject.egp" that is stored in
' the local directory C:\SAS\EG\Samples\4.2\.  The project file from this run will
' be saved in that same directory and called "RunWithDataSource1.egp".
'
' The program will then connect to a second repository/server combination
' and run the same project using the data from the second repository/server.
' The project file from this run will be saved in the file:
' C:\SAS\EG\Samples\4.2\RunWithDataSource2.egp
' 
' See the program comments above for more details on this subroutine and the 
' limitations of this program.
' 
'------------------------------------------------------------------------------
Sub dowork()
    ' NOTE: On Error Exit the subroutine
    Dim prjObject           'The project object for EG
    Dim prjName             'The Project we are running
    Dim save1File 	    'Save 1st project run
    Dim save2File           'Save 2nd project run
    Dim profile1   	    'First repository to connect to
    Dim profile2	 	    'Second repository to connect to
    Dim server 		    'The server to connect to on both repositories
    Dim Profiles		    'The list of Profiles identified on this client
    Dim Profile		    'A single profile from the list


    '-------------------
    ' Set the file names.  (These could be parameters.)
    '-------------------    
    prjName   =  "C:\SAS\EG\Samples\4.2\Test2ServersProject.egp"        'Project Name    
    save1File =  "C:\SAS\EG\Samples\4.2\RunWithDataSource1.egp"         'Save 1st project run
    save2File =  "C:\SAS\EG\Samples\4.2\RunWithDataSource2.egp"         'Save 2nd project run

    '---------------------------
    '  You must set up server profiles in EG before you can attach to different
    '  servers through the automation interface.  The data must be stored on
    '  in the same location on both servers.
    '---------------------------
    profile1 = "PROFILE1"
    profile2 = "PROFILE2"

    ' Set up the 4.2 project and open it.
    Set app = CreateObject("SASEGObjectModel.Application.4.2")
    If Checkerror("CreateObject") = True Then
        Exit Sub
    End If    

    ' Get the list of profiles from the client PC
    Set Profiles =  app.Profiles()
    
MsgBox "Starting processing for " + profile1    
    '--------------------------------------------------------
    ' REPOSITORY 1
    '--------------------------------------------------------
    ' Connect to repository 1
    app.SetActiveProfile(profile1)

    ' open the project
    Set prjObject = app.Open(prjName, "")
      If Checkerror("app.Open") = True Then
        Exit Sub
      End If

    ' Run the project against repository 1
    prjObject.run
      If Checkerror("Project.run") = True Then
        Exit Sub
      End If

    ' Save the new project produced to a local directory
    prjObject.SaveAs save1File
      If Checkerror("Project.SaveAs") = True Then
        Exit Sub
      End If

    ' Close the project
    prjObject.Close
      If Checkerror("Project.Close") = True Then
        Exit Sub
      End If

    '--------------------------------------------------------
MsgBox "Starting processing for " + profile2    
    
    '--------------------------------------------------------
    ' REPOSITORY 2
    '--------------------------------------------------------
    ' Connect to repository 2
    app.SetActiveProfile(profile2)

    ' open the project
    Set prjObject = app.Open(prjName, "")
      If Checkerror("app.Open") = True Then
        Exit Sub
      End If

    ' Run the project against repository 2
    prjObject.run
      If Checkerror("Project.run") = True Then
        Exit Sub
      End If

    ' Save the new project produced to a local directory
    prjObject.SaveAs save2File
      If Checkerror("Project.SaveAs") = True Then
        Exit Sub
      End If

    ' Close the project
    prjObject.Close
      If Checkerror("Project.Close") = True Then
        Exit Sub
      End If
    '--------------------------------------------------------

End Sub    

'------------------------------------------------------------------------------
' Checkerror
'------------------------------------------------------------------------------
' Looks for an error message and displays it in a message box, but only
' if the line that starts with:
' ' MsgBox strmsg
' has had the single quote removed.
'------------------------------------------------------------------------------
Function Checkerror(fnName)
    Checkerror = False
    
    Dim strmsg
    Dim errNum
    
    If Err.Number <> 0 Then
        strmsg = "Error #" & Hex(Err.Number) & vbCrLf & "In Function " & fnName & vbCrLf & Err.Description
        ' MsgBox strmsg  'Uncomment this line if you want to be notified via MessageBox of Errors in the script.
        Checkerror = True
    End If
         
End Function
